==> bugbattle_sdk-3.0.7.tar.gz: ios/Classes/BugbattleSdkPlugin.m <==
#import "BugbattleSdkPlugin.h"

@implementation BugbattleSdkPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"bugbattle_sdk"
            binaryMessenger:[registrar messenger]];
  BugbattleSdkPlugin* instance = [[BugbattleSdkPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (UIColor *) colorFromHexCode:(NSString *)hexString {
    NSString *cleanString = [hexString stringByReplacingOccurrencesOfString:@"#" withString:@""];
    if([cleanString length] == 3) {
        cleanString = [NSString stringWithFormat:@"%@%@%@%@%@%@",
                        [cleanString substringWithRange:NSMakeRange(0, 1)],[cleanString substringWithRange:NSMakeRange(0, 1)],
                        [cleanString substringWithRange:NSMakeRange(1, 1)],[cleanString substringWithRange:NSMakeRange(1, 1)],
                        [cleanString substringWithRange:NSMakeRange(2, 1)],[cleanString substringWithRange:NSMakeRange(2, 1)]];
    }
    if([cleanString length] == 6) {
        cleanString = [cleanString stringByAppendingString:@"ff"];
    }
    
    unsigned int baseValue;
    [[NSScanner scannerWithString:cleanString] scanHexInt:&baseValue];
    
    float red = ((baseValue >> 24) & 0xFF)/255.0f;
    float green = ((baseValue >> 16) & 0xFF)/255.0f;
    float blue = ((baseValue >> 8) & 0xFF)/255.0f;
    float alpha = ((baseValue >> 0) & 0xFF)/255.0f;
    
    return [UIColor colorWithRed:red green:green blue:blue alpha:alpha];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
   if ([@"initWithToken" isEqualToString:call.method]) {
     if ([call.arguments[@"activationMethod"] isEqualToString: @"SHAKE"]) {
        [BugBattle initWithToken: call.arguments[@"apiKey"] andActivationMethod: SHAKE];
     } 
     else if ([call.arguments[@"activationMethod"] isEqualToString: @"THREE_FINGER_DOUBLE_TAB"]) {
       [BugBattle initWithToken: call.arguments[@"apiKey"] andActivationMethod: THREE_FINGER_DOUBLE_TAB];
     } 
     else if ([call.arguments[@"activationMethod"] isEqualToString: @"SCREENSHOT"]) {
       [BugBattle initWithToken: call.arguments[@"apiKey"] andActivationMethod: SCREENSHOT];
     }
     else {
        [BugBattle initWithToken: call.arguments[@"apiKey"] andActivationMethod: NONE];
     }
     [BugBattle setApplicationType: FLUTTER];
  } else if([@"startBugReporting" isEqualToString:call.method]) {
    [BugBattle startBugReporting];
  }
  else if([@"setCustomerEmail" isEqualToString:call.method]) {
    [BugBattle setCustomerEmail: call.arguments[@"email"]];
  }
  else if([@"attachCustomData" isEqualToString:call.method]) {
    [BugBattle attachCustomData: call.arguments[@"customData"]];
  }
  else if([@"enablePrivacyPolicy" isEqualToString:call.method]) {
    [BugBattle enablePrivacyPolicy: call.arguments[@"enable"]];
  }
  else if([@"setPrivacyPolicyUrl" isEqualToString:call.method]) {
    [BugBattle setPrivacyPolicyUrl: call.arguments[@"url"]];
  }
  else if([@"setNavigationBarTint" isEqualToString:call.method]) {
    [BugBattle setNavigationBarTint: [self colorFromHexCode: call.arguments[@"color"]]];
  }
  else if([@"setNavigationTint" isEqualToString:call.method]) {
    [BugBattle setNavigationTint: [self colorFromHexCode: call.arguments[@"color"]]];
  }
  else if([@"setNavigationBarTitleColor" isEqualToString:call.method]) {
    [BugBattle setNavigationBarTitleColor: [self colorFromHexCode: call.arguments[@"color"]]];
  }
  else if([@"setApiUrl" isEqualToString:call.method]) {
    [BugBattle setApiUrl: call.arguments[@"url"]];
  }
  else {
    result(FlutterMethodNotImplemented);
  }
}

@end

==> bugbattle_sdk-3.1.0.tar.gz: ios/Classes/BugbattleSdkPlugin.m <==
#import "BugbattleSdkPlugin.h"

@implementation BugbattleSdkPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"bugbattle_sdk"
            binaryMessenger:[registrar messenger]];
  BugbattleSdkPlugin* instance = [[BugbattleSdkPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (UIColor *) colorFromHexCode:(NSString *)hexString {
    NSString *cleanString = [hexString stringByReplacingOccurrencesOfString:@"#" withString:@""];
    if([cleanString length] == 3) {
        cleanString = [NSString stringWithFormat:@"%@%@%@%@%@%@",
                        [cleanString substringWithRange:NSMakeRange(0, 1)],[cleanString substringWithRange:NSMakeRange(0, 1)],
                        [cleanString substringWithRange:NSMakeRange(1, 1)],[cleanString substringWithRange:NSMakeRange(1, 1)],
                        [cleanString substringWithRange:NSMakeRange(2, 1)],[cleanString substringWithRange:NSMakeRange(2, 1)]];
    }
    if([cleanString length] == 6) {
        cleanString = [cleanString stringByAppendingString:@"ff"];
    }
    
    unsigned int baseValue;
    [[NSScanner scannerWithString:cleanString] scanHexInt:&baseValue];
    
    float red = ((baseValue >> 24) & 0xFF)/255.0f;
    float green = ((baseValue >> 16) & 0xFF)/255.0f;
    float blue = ((baseValue >> 8) & 0xFF)/255.0f;
    float alpha = ((baseValue >> 0) & 0xFF)/255.0f;
    
    return [UIColor colorWithRed:red green:green blue:blue alpha:alpha];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
   if ([@"initWithToken" isEqualToString:call.method]) {
     if ([call.arguments[@"activationMethod"] isEqualToString: @"SHAKE"]) {
        [BugBattle initWithToken: call.arguments[@"apiKey"] andActivationMethod: SHAKE];
     } 
     else if ([call.arguments[@"activationMethod"] isEqualToString: @"THREE_FINGER_DOUBLE_TAB"]) {
       [BugBattle initWithToken: call.arguments[@"apiKey"] andActivationMethod: THREE_FINGER_DOUBLE_TAB];
     } 
     else if ([call.arguments[@"activationMethod"] isEqualToString: @"SCREENSHOT"]) {
       [BugBattle initWithToken: call.arguments[@"apiKey"] andActivationMethod: SCREENSHOT];
     }
     else {
        [BugBattle initWithToken: call.arguments[@"apiKey"] andActivationMethod: NONE];
     }
     [BugBattle setApplicationType: FLUTTER];
  } 
  else if([@"initializeMany" isEqualToString:call.method]) {
    NSMutableArray *activationMethods = [NSMutableArray array];
    NSArray *activationMethodsAsStrings = call.arguments[@"activationMethods"];

    for(int i = 0; i < [activationMethodsAsStrings count]; i++) {
      if ([[activationMethodsAsStrings objectAtIndex:i] isEqualToString: @"SHAKE"]) {
          [activationMethods addObject: @(SHAKE)];
      } 
      else if ([[activationMethodsAsStrings objectAtIndex:i] isEqualToString: @"THREE_FINGER_DOUBLE_TAB"]) {
        [activationMethods addObject: @(THREE_FINGER_DOUBLE_TAB)];
      } 
      else if ([[activationMethodsAsStrings objectAtIndex:i] isEqualToString: @"SCREENSHOT"]) {
        [activationMethods addObject: @(SCREENSHOT)];
      }
      else {
          [activationMethods addObject: @(NONE)];
      }
    }

    [BugBattle initWithToken: call.arguments[@"apiKey"] andActivationMethods: activationMethods];
    [BugBattle setApplicationType: FLUTTER];
  } 
  else if([@"startBugReporting" isEqualToString:call.method]) {
    [BugBattle startBugReporting];
  }
  else if([@"enableReplays" isEqualToString:call.method]) {
    [BugBattle enableReplays: true];
  }
  else if([@"setCustomerEmail" isEqualToString:call.method]) {
    [BugBattle setCustomerEmail: call.arguments[@"email"]];
  }
  else if([@"attachCustomData" isEqualToString:call.method]) {
    [BugBattle attachCustomData: call.arguments[@"customData"]];
  }
  else if([@"enablePrivacyPolicy" isEqualToString:call.method]) {
    [BugBattle enablePrivacyPolicy: call.arguments[@"enable"]];
  }
  else if([@"setPrivacyPolicyUrl" isEqualToString:call.method]) {
    [BugBattle setPrivacyPolicyUrl: call.arguments[@"url"]];
  }
  else if([@"setNavigationBarTint" isEqualToString:call.method]) {
    [BugBattle setNavigationBarTint: [self colorFromHexCode: call.arguments[@"color"]]];
  }
  else if([@"setNavigationTint" isEqualToString:call.method]) {
    [BugBattle setNavigationTint: [self colorFromHexCode: call.arguments[@"color"]]];
  }
  else if([@"setNavigationBarTitleColor" isEqualToString:call.method]) {
    [BugBattle setNavigationBarTitleColor: [self colorFromHexCode: call.arguments[@"color"]]];
  }
  else if([@"setApiUrl" isEqualToString:call.method]) {
    [BugBattle setApiUrl: call.arguments[@"url"]];
  }
  else {
    result(FlutterMethodNotImplemented);
  }
}

@end
